@@ -1,7 +1,7 @@
 #ifndef CONFIG_H		// -*- c++ -*-
 #define CONFIG_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "util/configfile.h"
 #include <sigc++/object.h>
@@ -33,17 +33,14 @@ struct FVar: public Config::FloatVar, public GuiVar {
     FloatVar(name_), GuiVar(desc_) {}
 };
 
-/**
- * Passepartout-specific config file reader.
- */
+/// Passepartout-specific config file reader.
 class PFile: public Config::File, public SigC::Object {
 public:
 
   /// The global instance.
   static PFile instance;
 
-  FVar ReshapeBoxSize, ScreenResolution, DefaultResolution, 
-    ZoomLevel, StartPage;
+  FVar ReshapeBoxSize, DefaultResolution, ZoomLevel, StartPage;
   BVar Landscape, FakeTransparency, SingleSided;
   SVar PaperName, PrintCommand, FontPath, StylesheetPath,
     DefaultStylesheet, DocTemplatePath, PSInterpreter, PSViewer,
