@@ -1,7 +1,7 @@
 #ifndef PAGESEL_H		// -*- c++ -*-
 #define PAGESEL_H
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 
 #include "docview.h"
@@ -15,13 +15,13 @@
 
 class Pagesel: public Gtk::HBox {
 public:
-  Pagesel(Document_View &docview);
+  Pagesel(DocumentView &docview);
   ~Pagesel();
 
   Gtk::OptionMenu &get_optionmenu() {return pages;}
 
 private:
-  Document_View &document_view;
+  DocumentView &document_view;
   Gtk::Menu menu;
   Gtk::OptionMenu pages;
   Gtk::Button left, right;
@@ -31,13 +31,13 @@ private:
   void update();
 };
 
-class Template_Page_Dialog: public DialogWrap {
+class TemplatePageDialog: public DialogWrap {
 public:
-  Template_Page_Dialog(Gtk::Window &parent, Document_View &document_view_);
+  TemplatePageDialog(Gtk::Window &parent, DocumentView &document_view_);
   void show_it(bool new_page_ = false, int page_num_ = 0);
 
 private:
-  Document_View &document_view;
+  DocumentView &document_view;
 
   Glib::RefPtr<Gtk::ListStore> tree_model;
   Gtk::TreeView page_list;
