@@ -1,6 +1,8 @@
+///
+// Copyright (C) 2003, 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include "dialogwrap.h"
 #include "wmisc.h"
-#include <gtkmm.h>
 
 DialogWrap::DialogWrap(const std::string& name)
   : Gtk::Dialog(name + " - Passepartout",
