@@ -1,5 +1,5 @@
 ///
-// Copyright (C) 2002, 2003, Fredrik Arnerup & Rasmus Kaj, See COPYING
+// Copyright (C) 2002 - 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
 ///
 #include "window.h"
 
@@ -45,7 +45,6 @@
 #include "propertiesdialog.h"
 #include "docpropsdialog.h"
 #include "streamdialog.h"
-#include "undodialog.h"
 #include "pagesel.h"
 
 namespace{
@@ -270,11 +269,6 @@ void FrameWindow::constructor_common() {
 
   show_all();
 
-#ifndef ENABLE_UNDO
-  undo_item->hide();
-  redo_item->hide();
-#endif
-
   active_window = this;
 
   // make sure not everything is visible and that document dependent
@@ -422,8 +416,6 @@ void FrameWindow::on_document_changed() {
     (slot(*this, &FrameWindow::on_document_filename_changed));
   set_filename(basename(docmeta.get_filename()));
 
-//   undo_item->set_sensitive(on && document->get_undo_count());
-//   redo_item->set_sensitive(on && document->get_redo_count());
 }
 
 void FrameWindow::new_document() {
@@ -477,7 +469,6 @@ void FrameWindow::close() {
     document_view.set_document(DocMeta(null));
     PropertiesDialog::instance().set_document(null);
     StreamDialog::instance().set_document(null);
-    UndoDialog::instance().set_document(null);
     set_filename("");
   }
 }
@@ -527,9 +518,6 @@ bool FrameWindow::on_focus_in_event(GdkEventFocus *event) {
   StreamDialog::instance().set_transient_for(*this);
   StreamDialog::instance().set_document(document);
 
-  UndoDialog::instance().set_transient_for(*this);
-  UndoDialog::instance().set_document(document);
-
   return false;
 }
 
