@@ -1,8 +1,12 @@
+///
+// Copyright (C) 2003, 2004, Fredrik Arnerup & Rasmus Kaj, See COPYING
+///
 #include "pagedstream.hh"
 #include "util/filesys.h"
 #include <fstream>
 #include <sstream>
 #include <iostream>
+#include <vector>
 
 xml2ps::PagedStream::PagedStream() 
   : current_part(0)
@@ -35,12 +39,12 @@ void xml2ps::PagedStream::appendPage(unsigned int number, std::ostream& out)
 {
   const std::string inname = filename(number);
   std::ifstream in(inname.c_str());
-  const size_t blocksize = 4*1024; // Todo:  Value?
-  std::auto_ptr<char> buf(new char[blocksize]);
-  while(in.read(&*buf, blocksize)) {
-    out.write(&*buf, in.gcount());
+  const size_t blocksize = 4*1024; /// \todo  Value?
+  std::vector<char> buf(blocksize);  // use string instead?
+  while(in.read(&buf[0], buf.size())) {
+    out.write(&buf[0], in.gcount());
   }
-  out.write(&*buf, in.gcount());
+  out.write(&buf[0], in.gcount());
 }
 
 std::string xml2ps::PagedStream::filename(unsigned int number) const {
